Description Usage Arguments Value Examples
Update the d parameter for each cluster
1 2 3 4 5 6 7 8 9 | update_R_vector(
cluster_data,
number_of_clusters,
probability_matrix,
sequence,
sigma_list,
m_list,
nbasis
)
|
cluster_data |
The matrix containing rows corresponding the curves |
number_of_clusters |
The total number of clusters |
probability_matrix |
A matrix in which the rows represent the probabilities that the curve is in each of the clusters |
sequence |
The sequence used to generate the clusters |
nbasis |
The number of basis functions |
A_vector |
A vector |
R_vector |
A vector |
sigma_vector |
A vector of the updated sigma parameters for each cluster |
m_vector |
A vector of the updated m parameters for each cluster |
A vector of the updated R parameters for each cluster
1 | update_R_vector(number_of_clusters, A_vector, R_vector, probability_matrix, sequence, nbasis)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.